==> azure-devops-repository-archiver-0.0.12.tar.gz: package/lib/archiver.d.ts <==
import { aws_kms as kms, aws_logs as logs, aws_sns as sns, aws_s3 as s3 } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { ArchiverProperties } from './archiverProperties';
export declare class Archiver extends Construct {
    props: ArchiverProperties;
    /**
     * Log group used by the CodeBuild projects.
     *
     * @type {LogGroup}
     * @memberof Archiver
     */
    logGroup: logs.LogGroup;
    /**
     *The KMS key used to encrypt the logs.
     *
     * @type {kms.Key}
     * @memberof Archiver
     */
    logGroupKmsKey: kms.Key;
    /**
     *The S3 bucket used to store the git repositories archive.
     *
     * @type {s3.Bucket}
     * @memberof Archiver
     */
    bucket: s3.Bucket;
    /**
     * SNS topic to send configured bucket events to.
     *
     * @type {sns.Topic}
     * @memberof Archiver
     */
    topic: sns.Topic;
    constructor(scope: Construct, id: string, props: ArchiverProperties);
    private createCfnOutputs;
    private createLogGroup;
    /**
     *Create the S3 bucket that will later store the repositories.
     *
     * @private
     * @return {*}
     * @memberof Archiver
     */
    private createArchiveBucket;
    private createLogGroupKey;
    /**
     * Creates for each backup configuration a separate CodeBuild project.
     *
     * @private
     * @memberof Archiver
     */
    private createProjects;
    /**
     * Create a CodeBuild project.
     *
     * @private
     * @param {BackupConfiguration} element
     * @return {*}
     * @memberof Archiver
     */
    private createProject;
    private createBatchConfiguration;
}
export interface BatchListElement {
    readonly identifier: string;
    readonly env: Object;
}

==> azure-devops-repository-archiver-0.0.23.tar.gz: package/lib/archiver.d.ts <==
import { aws_kms as kms, aws_logs as logs, aws_sns as sns, aws_s3 as s3 } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { ArchiverProperties } from './archiverProperties';
export declare class Archiver extends Construct {
    props: ArchiverProperties;
    /**
     * Log group used by the CodeBuild projects.
     *
     * @type {LogGroup}
     * @memberof Archiver
     */
    logGroup: logs.LogGroup;
    /**
     *The KMS key used to encrypt the logs and the SNS topic.
     *
     * @type {kms.Key}
     * @memberof Archiver
     */
    kmsKey: kms.Key;
    /**
     *The S3 bucket used to store the git repositories archive.
     *
     * @type {s3.Bucket}
     * @memberof Archiver
     */
    bucket: s3.Bucket;
    /**
     * SNS topic to send configured bucket events to.
     *
     * @type {sns.Topic}
     * @memberof Archiver
     */
    topic: sns.Topic;
    constructor(scope: Construct, id: string, props: ArchiverProperties);
    /**
     * Set up the S3-related event notifcations.
     *
     * @private
     * @memberof Archiver
     */
    private createS3Notifications;
    private createCfnOutputs;
    private createLogGroup;
    /**
     *Create the S3 bucket that will later store the repositories.
     *
     * @private
     * @return {*}
     * @memberof Archiver
     */
    private createArchiveBucket;
    private createKey;
    /**
     * Creates for each backup configuration a separate CodeBuild project.
     *
     * @private
     * @memberof Archiver
     */
    private createProjects;
    private createCloudwatchRule;
    /**
     * Create a CodeBuild project.
     *
     * @private
     * @param {BackupConfiguration} element
     * @return {*}
     * @memberof Archiver
     */
    private createProject;
    private createBatchConfiguration;
}
export interface BatchListElement {
    readonly identifier: string;
    readonly env: Object;
}
